@@ -32,8 +32,11 @@ def expr_eval(string, context={}):
     context['time'] = time
     if isinstance(string, basestring):
 #        return eval(string, context)
-        string=string.replace("'active_id'","active_id")
-        temp=eval(string, context)
+        try:
+            string  =string.replace("'active_id'","active_id")
+            temp = eval(string, context)
+        except:
+            return {}
         return temp
     else:
         return string
@@ -42,7 +45,7 @@ def launch_browser(url):
     import webbrowser
     import sys
     if sys.platform == 'win32':
-        webbrowser.open(url)
+        webbrowser.open(url.decode('utf-8'))
     else:
         import os
         pid = os.fork()
