@@ -174,6 +174,15 @@ class BinaryField(CharField):
     def get_size_name(self):
         return "%s.size" % self.name
 
+    def validate(self, model):
+        ok = True
+        if bool(self.get_state_attrs(model).get('required', 0)):
+            name = "%s.size" % self.name
+            if not model.value.get(name, False):
+                ok = False
+        self.get_state_attrs(model)['valid'] = ok
+        return ok
+
     def set(self, model, value, test_state=True, modified=False, get_binary_size=True):
         self.__check_model(model)
         if model.is_wizard():
@@ -183,6 +192,8 @@ class BinaryField(CharField):
         model.value[name] = value
         if (not get_binary_size) and value:
             model.value[self.get_size_name()] = tools.human_size(len(value))
+        if not value:
+            model.value[self.get_size_name()] = ""
         if modified:
             model.modified = True
             model.modified_fields.setdefault(self.name)
